@@ -233,7 +233,10 @@ def parse_json_to_csv(data: list[list[str]]) -> list[list[str]]:
             column, value = [item.strip() for item in pair.split(':')]
             if i == 0:
                 columns.append(column.replace('"', ''))
-            values.append(value.replace('"', ''))
+            if value == 'null':
+                values.append('')
+            else:
+                values.append(value.replace('"', ''))
             
         if i == 0:
             converted_data.append(columns)
